@@ -49,7 +49,7 @@ class FileSystem(object):
         :param kwargs: Customizable arguments...
             block_size
             cache_options
-        :return:    A file-like object.
+        :return:    A file-like object with an __exit__ method.
         """
 
 
@@ -228,6 +228,9 @@ class S3Connection(FileSystem):
                 rdr.seekable = lambda: False
                 rdr.closed = False
                 rdr.flush = lambda: None
+                # TODO and to support 'with'
+                rdr.__enter__ = lambda *a, **k: rdr
+                rdr.__exit__ = lambda *a, **k: rdr.close()
                 return TextIOWrapper(rdr, 'utf-8')
             return resp["Body"]
         if self._read_only:
