@@ -22,9 +22,12 @@ def connect_to_database(uri: str, library: str=None, for_write: bool=False, **kw
         libraries.append("psycopg2")
     if uri_parts[0] == "mysql":
         libraries.append("pymysql")
+    if uri_parts[0] == "mssql":
+        libraries.append("pymssql")
     if uri_parts[0] == "sqlite":
         libraries.append("sqlite")
     params = _process_params(uri, **kwargs)
+    params.pop("scheme", None)
     for lib in libraries:
         if lib in METHODS:
             conn = METHODS[lib](**params, for_write=for_write)
@@ -85,6 +88,27 @@ def connect_pymysql(host, port=None, username=None, password=None, database=None
     return conn
 
 
+def connect_pymssql(host, port=None, username=None, password=None, database=None, autocommit=True, for_write: bool=False, **kwargs):
+    try:
+        import pymssql
+    except ImportError:
+        raise Exception("MS SQL library not installed")
+    more = {}
+    if "timeout" in kwargs:
+        more["timeout"] = int(kwargs["timeout"])
+    conn = pymssql.connect(
+        server=host,
+        user=username,
+        password=password,
+        database=database,
+        autocommit=autocommit,
+        **more
+    )
+    if not for_write:
+        _set_conn_read_only(conn)
+    return conn
+
+
 def connect_psycopg2(host, port=None, username=None, password=None, database=None, autocommit=True, for_write: bool=False, **kwargs):
     try:
         import psycopg2
@@ -130,6 +154,7 @@ def _set_conn_read_only(conn):
 METHODS = {
     "pymysql": connect_pymysql,
     "psycopg2": connect_psycopg2,
+    "pymssql": connect_pymssql,
     "sqlite": connect_sqlite
 }
 
